==> dagster_pagerduty-0.12.14rc0-py3-none-any.whl: dagster_pagerduty_tests/test_hooks.py <==
import responses
from dagster import ModeDefinition, execute_pipeline, pipeline, solid
from dagster_pagerduty import pagerduty_resource
from dagster_pagerduty.hooks import pagerduty_on_failure


class SomeUserException(Exception):
    pass


@responses.activate
def test_failure_hook_on_solid_instance():
    def my_summary_fn(_):
        return "A custom summary"

    @solid
    def pass_solid(_):
        pass

    @solid
    def fail_solid(_):
        raise SomeUserException()

    @pipeline(mode_defs=[ModeDefinition(resource_defs={"pagerduty": pagerduty_resource})])
    def a_pipeline():
        pass_solid.with_hooks(hook_defs={pagerduty_on_failure("info")})()
        pass_solid.alias("solid_with_hook").with_hooks(hook_defs={pagerduty_on_failure("info")})()
        fail_solid.alias("fail_solid_without_hook")()
        fail_solid.with_hooks(
            hook_defs={pagerduty_on_failure(severity="info", summary_fn=my_summary_fn)}
        )()

    with responses.RequestsMock() as rsps:
        rsps.add(
            rsps.POST,
            "https://events.pagerduty.com/v2/enqueue/",
            status=202,
            json={"status": "success", "message": "Event processed"},
        )
        result = execute_pipeline(
            a_pipeline,
            run_config={
                "resources": {
                    "pagerduty": {"config": {"routing_key": "0123456789abcdef0123456789abcdef"}}
                }
            },
            raise_on_error=False,
        )
        assert not result.success
        assert len(rsps.calls) == 1


@responses.activate
def test_failure_hook_decorator():
    @solid
    def pass_solid(_):
        pass

    @solid
    def fail_solid(_):
        raise SomeUserException()

    @pagerduty_on_failure(severity="info", dagit_base_url="localhost:3000")
    @pipeline(mode_defs=[ModeDefinition(resource_defs={"pagerduty": pagerduty_resource})])
    def a_pipeline():
        pass_solid()
        fail_solid()
        fail_solid.alias("another_fail_solid")()

    with responses.RequestsMock() as rsps:
        rsps.add(
            rsps.POST,
            "https://events.pagerduty.com/v2/enqueue/",
            status=202,
            json={"status": "success", "message": "Event processed"},
        )
        result = execute_pipeline(
            a_pipeline,
            run_config={
                "resources": {
                    "pagerduty": {"config": {"routing_key": "0123456789abcdef0123456789abcdef"}}
                }
            },
            raise_on_error=False,
        )
        assert not result.success
        assert len(rsps.calls) == 2

==> dagster_pagerduty-0.14.5rc0-py3-none-any.whl: dagster_pagerduty_tests/test_hooks.py <==
import responses
from dagster_pagerduty import pagerduty_resource
from dagster_pagerduty.hooks import pagerduty_on_failure

from dagster import job, op


class SomeUserException(Exception):
    pass


@responses.activate
def test_failure_hook_on_op_instance():
    def my_summary_fn(_):
        return "A custom summary"

    @op
    def pass_op(_):
        pass

    @op
    def fail_op(_):
        raise SomeUserException()

    @job(resource_defs={"pagerduty": pagerduty_resource})
    def a_job():
        pass_op.with_hooks(hook_defs={pagerduty_on_failure("info")})()
        pass_op.alias("op_with_hook").with_hooks(hook_defs={pagerduty_on_failure("info")})()
        fail_op.alias("fail_op_without_hook")()
        fail_op.with_hooks(
            hook_defs={pagerduty_on_failure(severity="info", summary_fn=my_summary_fn)}
        )()

    with responses.RequestsMock() as rsps:
        rsps.add(
            rsps.POST,
            "https://events.pagerduty.com/v2/enqueue/",
            status=202,
            json={"status": "success", "message": "Event processed"},
        )
        result = a_job.execute_in_process(
            run_config={
                "resources": {
                    "pagerduty": {"config": {"routing_key": "0123456789abcdef0123456789abcdef"}}
                }
            },
            raise_on_error=False,
        )
        assert not result.success
        assert len(rsps.calls) == 1


@responses.activate
def test_failure_hook_decorator():
    @op
    def pass_op(_):
        pass

    @op
    def fail_op(_):
        raise SomeUserException()

    @job(
        resource_defs={"pagerduty": pagerduty_resource},
        hooks={pagerduty_on_failure(severity="info", dagit_base_url="localhost:3000")},
    )
    def a_job():
        pass_op()
        fail_op()
        fail_op.alias("another_fail_op")()

    with responses.RequestsMock() as rsps:
        rsps.add(
            rsps.POST,
            "https://events.pagerduty.com/v2/enqueue/",
            status=202,
            json={"status": "success", "message": "Event processed"},
        )
        result = a_job.execute_in_process(
            run_config={
                "resources": {
                    "pagerduty": {"config": {"routing_key": "0123456789abcdef0123456789abcdef"}}
                }
            },
            raise_on_error=False,
        )
        assert not result.success
        assert len(rsps.calls) == 2
